@@ -4,7 +4,6 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id$
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,9 +11,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
 
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
@@ -29,9 +25,15 @@
 
 #include "joytest.h"
 
+// the application icon (under Windows it is in resources and even
+// though we could still include the XPM here it would be unused)
+#ifndef wxHAS_IMAGES_IN_RESOURCES
+    #include "../sample.xpm"
+#endif
+
 MyFrame *frame = NULL;
 
-IMPLEMENT_APP(MyApp)
+wxIMPLEMENT_APP(MyApp);
 
 // For drawing lines in a canvas
 long xpos = -1;
@@ -49,12 +51,12 @@ bool MyApp::OnInit()
     wxJoystick stick(wxJOYSTICK1);
     if (!stick.IsOk())
     {
-        wxMessageBox(wxT("No joystick detected!"));
+        wxMessageBox("No joystick detected!");
         return false;
     }
 
 #if wxUSE_SOUND
-    m_fire.Create(wxT("buttonpress.wav"));
+    m_fire.Create("buttonpress.wav");
 #endif // wxUSE_SOUND
 
     m_minX = stick.GetXMin();
@@ -64,7 +66,7 @@ bool MyApp::OnInit()
 
     // Create the main frame window
 
-    frame = new MyFrame(NULL, wxT("Joystick Demo"), wxDefaultPosition,
+    frame = new MyFrame(NULL, "Joystick Demo", wxDefaultPosition,
         wxSize(500, 400), wxDEFAULT_FRAME_STYLE | wxHSCROLL | wxVSCROLL);
 
     frame->SetIcon(wxICON(sample));
@@ -72,31 +74,29 @@ bool MyApp::OnInit()
     // Make a menubar
     wxMenu *file_menu = new wxMenu;
 
-    file_menu->Append(JOYTEST_QUIT, wxT("&Exit"));
+    file_menu->Append(JOYTEST_QUIT, "&Exit");
 
     wxMenuBar *menu_bar = new wxMenuBar;
 
-    menu_bar->Append(file_menu, wxT("&File"));
+    menu_bar->Append(file_menu, "&File");
 
     // Associate the menu bar with the frame
     frame->SetMenuBar(menu_bar);
 
 #if wxUSE_STATUSBAR
     frame->CreateStatusBar();
-    frame->SetStatusText(wxString::Format(wxT("Device [%s] (PID:[%i] MID:[%i]) Ready... # of joysticks:[%i]"), stick.GetProductName().c_str(), stick.GetProductId(), stick.GetManufacturerId(), wxJoystick::GetNumberJoysticks()));
+    frame->SetStatusText(wxString::Format("Device [%s] (PID:[%i] MID:[%i]) Ready... # of joysticks:[%i]", stick.GetProductName(), stick.GetProductId(), stick.GetManufacturerId(), wxJoystick::GetNumberJoysticks()));
 #endif // wxUSE_STATUSBAR
 
     frame->CenterOnScreen();
     frame->Show(true);
 
-    SetTopWindow(frame);
-
     return true;
 }
 
-BEGIN_EVENT_TABLE(MyCanvas, wxScrolledWindow)
+wxBEGIN_EVENT_TABLE(MyCanvas, wxScrolledWindow)
     EVT_JOYSTICK_EVENTS(MyCanvas::OnJoystickEvent)
-END_EVENT_TABLE()
+wxEND_EVENT_TABLE()
 
 // Define a constructor for my canvas
 MyCanvas::MyCanvas(wxWindow *parent, const wxPoint& pos, const wxSize& size):
@@ -115,52 +115,56 @@ MyCanvas::~MyCanvas()
 
 void MyCanvas::OnJoystickEvent(wxJoystickEvent& event)
 {
-    wxClientDC dc(this);
-
-    wxPoint pt(event.GetPosition());
-
-    // if negative positions are possible then shift everything up
-    int xmin = wxGetApp().m_minX;
-    int xmax = wxGetApp().m_maxX;
-    int ymin = wxGetApp().m_minY;
-    int ymax = wxGetApp().m_maxY;
-    if (xmin < 0) {
-        xmax += abs(xmin);
-        pt.x += abs(xmin);
-    }
-    if (ymin < 0) {
-        ymax += abs(ymin);
-        pt.y += abs(ymin);
-    }
-
-    // Scale to canvas size
-    int cw, ch;
-    GetSize(&cw, &ch);
-
-    pt.x = (long) (((double)pt.x/(double)xmax) * cw);
-    pt.y = (long) (((double)pt.y/(double)ymax) * ch);
-
-    if (xpos > -1 && ypos > -1 && event.IsMove() && event.ButtonIsDown())
+    // We don't have valid (x, y) coordinates for z-move events.
+    if ( !event.IsZMove() )
     {
-        dc.SetPen(*wxBLACK_PEN);
-        dc.DrawLine(xpos, ypos, pt.x, pt.y);
-    }
+        wxClientDC dc(this);
 
-    xpos = pt.x;
-    ypos = pt.y;
+        wxPoint pt(event.GetPosition());
+
+        // if negative positions are possible then shift everything up
+        int xmin = wxGetApp().m_minX;
+        int xmax = wxGetApp().m_maxX;
+        int ymin = wxGetApp().m_minY;
+        int ymax = wxGetApp().m_maxY;
+        if (xmin < 0) {
+            xmax += abs(xmin);
+            pt.x += abs(xmin);
+        }
+        if (ymin < 0) {
+            ymax += abs(ymin);
+            pt.y += abs(ymin);
+        }
+
+        // Scale to canvas size
+        int cw, ch;
+        GetSize(&cw, &ch);
+
+        pt.x = (long) (((double)pt.x/(double)xmax) * cw);
+        pt.y = (long) (((double)pt.y/(double)ymax) * ch);
+
+        if (xpos > -1 && ypos > -1 && event.IsMove() && event.ButtonIsDown())
+        {
+            dc.SetPen(*wxBLACK_PEN);
+            dc.DrawLine(xpos, ypos, pt.x, pt.y);
+        }
+
+        xpos = pt.x;
+        ypos = pt.y;
+    }
 
 #if wxUSE_STATUSBAR
     wxString buf;
     if (event.ButtonDown())
-        buf.Printf(wxT("Joystick (%d, %d) #%i Fire!"), pt.x, pt.y, event.GetButtonChange());
+        buf.Printf("Joystick (%ld, %ld) #%i Fire!", xpos, ypos, event.GetButtonOrdinal());
     else
-        buf.Printf(wxT("Joystick (%d, %d)  "), pt.x, pt.y);
+        buf.Printf("Joystick (%ld, %ld)  ", xpos, ypos);
 
 /*
     for(int i = 0; i < nButtons; ++i)
     {
-        buf += wxString(wxT("[")) +
-        ((event.GetButtonState() & (1 << i)) ? wxT("Y") : wxT("N")) + wxString(wxT("]"));
+        buf += wxString("[") +
+        ((event.GetButtonState() & (1 << i)) ? "Y" : "N") + wxString("]");
     }
 */
 
@@ -175,9 +179,9 @@ void MyCanvas::OnJoystickEvent(wxJoystickEvent& event)
 #endif // wxUSE_SOUND
 }
 
-BEGIN_EVENT_TABLE(MyFrame, wxFrame)
+wxBEGIN_EVENT_TABLE(MyFrame, wxFrame)
     EVT_MENU(JOYTEST_QUIT, MyFrame::OnQuit)
-END_EVENT_TABLE()
+wxEND_EVENT_TABLE()
 
 MyFrame::MyFrame(wxFrame *parent, const wxString& title, const wxPoint& pos,
     const wxSize& size, const long style)
